==> apache-openmeetings-7.2.0-src.tar.gz: openmeetings-webservice/src/main/java/org/apache/openmeetings/webservice/util/DateParamConverter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License") +  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.openmeetings.webservice.util;

import static org.apache.openmeetings.util.CalendarPatterns.ISO8601_DATETIME_FORMAT;
import static org.apache.openmeetings.util.CalendarPatterns.ISO8601_DATE_FORMAT;
import static org.apache.openmeetings.util.CalendarPatterns.ISO8601_FULL_FORMAT;

import java.text.ParseException;
import java.util.Date;

import javax.ws.rs.ext.ParamConverter;

import org.apache.commons.lang3.time.FastDateFormat;
import org.apache.wicket.util.string.Strings;

public class DateParamConverter implements ParamConverter<Date> {
	private static final FastDateFormat[] formats = new FastDateFormat[] { ISO8601_FULL_FORMAT, ISO8601_DATETIME_FORMAT, ISO8601_DATE_FORMAT };

	public static Date get(String val) {
		if (Strings.isEmpty(val)) {
			return null;
		}
		for (FastDateFormat df : formats) {
			try {
				return df.parse(val);
			} catch (ParseException e) {
				// no-op
			}
		}
		throw new IllegalArgumentException("Unparsable format: " + val);
	}

	@Override
	public Date fromString(String val) {
		return get(val);
	}

	@Override
	public String toString(Date val) {
		return ISO8601_FULL_FORMAT.format(val);
	}
}

==> apache-openmeetings-8.0.0-src.tar.gz: openmeetings-webservice/src/main/java/org/apache/openmeetings/webservice/util/DateParamConverter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License") +  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.openmeetings.webservice.util;

import static org.apache.openmeetings.util.CalendarPatterns.ISO8601_DATETIME_FORMAT;
import static org.apache.openmeetings.util.CalendarPatterns.ISO8601_DATE_FORMAT;
import static org.apache.openmeetings.util.CalendarPatterns.ISO8601_FULL_FORMAT;

import java.text.ParseException;
import java.util.Date;

import jakarta.ws.rs.ext.ParamConverter;

import org.apache.commons.lang3.time.FastDateFormat;
import org.apache.wicket.util.string.Strings;

public class DateParamConverter implements ParamConverter<Date> {
	private static final FastDateFormat[] formats = new FastDateFormat[] { ISO8601_FULL_FORMAT, ISO8601_DATETIME_FORMAT, ISO8601_DATE_FORMAT };

	public static Date get(String val) {
		if (Strings.isEmpty(val)) {
			return null;
		}
		for (FastDateFormat df : formats) {
			try {
				return df.parse(val);
			} catch (ParseException e) {
				// no-op
			}
		}
		throw new IllegalArgumentException("Unparsable format: " + val);
	}

	@Override
	public Date fromString(String val) {
		return get(val);
	}

	@Override
	public String toString(Date val) {
		return ISO8601_FULL_FORMAT.format(val);
	}
}
